//[mahjong-utils](../../../index.md)/[mahjongutils.shanten](../index.md)/[RegularShantenResult](index.md)/[shantenInfo](shanten-info.md)

# shantenInfo

[common]\
open override val [shantenInfo](shanten-info.md): [CommonShanten](../-common-shanten/index.md)

向听信息
